@@ -51,26 +51,34 @@ class Portal(with_metaclass(Plugin)):
 	`get_user`: Get the user for the current request
 	`login_user`: New login for a user
 	`login_request`: An anonymous user wants to login
-	`get_visible_content`: The content that the frontend shall present.
+	`get_visible_content`:
+		The content that the frontend shall present.
 		Should be filtered by the "user". Also gets "admin_mode", a
 		boolean indicating whether the user requested all the content
 		(and is authorized to do so)
-	`get_user_links`: Get the user links in the portal, filtered by "user"
+	`get_user_links`:
+		Get the user links in the portal, filtered by "user"
 		and "admin_mode"
-	`get_menu_links`: Get the menu links in the portal, filtered by "user"
+	`get_menu_links`:
+		Get the menu links in the portal, filtered by "user"
 		and "admin_mode"
-	`get_entries`: Get all entries of "content", which in turn was the
+	`get_entries`:
+		Get all entries of "content", which in turn was the
 		return value of `get_visible_content`
-	`get_folders`: Get all folders of "content", which in turn was the
+	`get_folders`:
+		Get all folders of "content", which in turn was the
 		return value of `get_visible_content`
-	`get_categories`: Get all categories of "content", which in turn was the
+	`get_categories`:
+		Get all categories of "content", which in turn was the
 		return value of `get_visible_content`
 	`auth_mode`: Mode for auth based on given "request"
 	`may_be_edited`: Whether a "user" may edit this portal
-	`get_meta`: Get some information about the portal itself, given
+	`get_meta`:
+		Get some information about the portal itself, given
 		"content" and "categories". Those were return values of
 		`get_visible_content` and `get_categories`.
-	`refresh`: Refresh the portal data if needed ("reason" acts as a hint).
+	`refresh`:
+		Refresh the portal data if needed ("reason" acts as a hint).
 		Thereby allows the object to cache its content.
 	`score`: If multiple portals are configured, use the one with the
 		highest score for a given "request".
@@ -285,6 +293,7 @@ class UMCPortal(Portal):
 	def get_entries(self, content):
 		entries = []
 		colors = {cat["id"]: cat["color"] for cat in content["umc_categories"] if cat["id"] != "_favorites_"}
+		locale = 'en_US'
 		for module in content["umc_modules"]:
 			if "apps" in module["categories"]:
 				continue
@@ -299,18 +308,23 @@ class UMCPortal(Portal):
 			entries.append({
 				"dn": self._entry_id(module),
 				"name": {
-					"en_US": module["name"],
+					locale: module["name"],
 				},
 				"description": {
-					"en_US": module["description"],
+					locale: module["description"],
+				},
+				"keywords": {
+					locale: ' '.join(module["keywords"]),
 				},
 				"linkTarget": "embedded",
+				"target": None,
 				"logo_name": logo_name,
 				"backgroundColor": color,
 				"links": [{
-					"locale": "en_US",
+					"locale": locale,
 					"value": "/univention/management/?header=try-hide&overview=false&menu=false#module={}:{}".format(module["id"], module.get("flavor", ""))
 				}],
+				# TODO: missing: in_portal, anonymous, activated, allowedGroups
 			})
 		return entries
 
