@@ -113,3 +113,10 @@ class NewPortalEntryLinkTarget(select):
 class LocalizedLink(translationTuple):
 	subsyntaxes = [(_('Language code (e.g. en_US)'), languageCode), (_('Link'), string)]
 	subsyntax_key_value = False
+
+
+class LocalizedKeywords(translationTuple):
+	"""
+	Syntax for translated keywords of a portal entry.
+	"""
+	subsyntaxes = [(_('Language code (e.g. en_US)'), languageCode), (_('Keywords'), string)]
